%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generates a resistance network from a 2D model
% containing conductivities.
%
% Carlos J. Cela, 2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function r = geteqnetwork( ys, xs, model )
n=0;
for i = 1:xs
  for j = 1:ys
    % Retrieve conductivity for cell
    sigma = model(j,i);

    % Skip if no resistor needed
    if sigma==0
      continue;
    end

    % Add 4 resistors for cell
    rn = 2/sigma;

    n = n+1;  % Top
    r(n,1) = getnodenumber(ys, xs, j, i);
    r(n,2) = getnodenumber(ys, xs, j, i+1);
    r(n,3) = rn;

    n = n+1;  % Bottom
    r(n,1) = getnodenumber(ys, xs, j+1, i);
    r(n,2) = getnodenumber(ys, xs, j+1, i+1);
    r(n,3) = rn;

    n = n+1;  % Left
    r(n,1) = getnodenumber(ys, xs, j, i);
    r(n,2) = getnodenumber(ys, xs, j+1, i);
    r(n,3) = rn;

    n = n+1;  % Right
    r(n,1) = getnodenumber(ys, xs, j, i+1);
    r(n,2) = getnodenumber(ys, xs, j+1, i+1);
    r(n,3) = rn;

  end
end

% Add 1A current source between top-left and bottom-right corners
i = [ getnodenumber(ys, xs, 1, 1) getnodenumber(ys, xs, ys, xs) 1];

end
